@@ -28,19 +28,18 @@
 #include <bits/std_clocale.h>
 #include <bits/std_cstring.h>
 #include <bits/std_cassert.h>
+#include <bits/std_cctype.h>
 #include <bits/std_limits.h>
 #include <bits/std_exception.h>
 #include <bits/std_stdexcept.h>
 #include <bits/std_locale.h>
+#include <bits/std_istream.h>
+#include <bits/std_ostream.h>
 #include <bits/std_vector.h>
 
 namespace std {
 
-// Implementation of locale::_Impl members
-//////////////////////////////////////////
-
-
-  // destructor
+  // locale::_Impl
   locale::_Impl::~_Impl() throw ()
   {
     std::vector<facet*>::iterator it = _M_facets->begin();
@@ -50,7 +49,6 @@ namespace std {
     delete _M_category_names;
   }
 
-  // copy constructors
   locale::_Impl::_Impl(size_t __numfacets, size_t __refs)
   : _M_num_references(__refs - 1)
     //  , _M_facets (numfacets, (facet*)0)
@@ -59,7 +57,6 @@ namespace std {
   , _M_cached_name_ok(false)
   , _M_cached_name(string ("*"))
   { 
-#if 1
     typedef vector<facet*, __STL_DEFAULT_ALLOCATOR(facet*) > __vec_facet;
     typedef vector<string, __STL_DEFAULT_ALLOCATOR(string) > __vec_string;
     try {
@@ -76,7 +73,6 @@ namespace std {
       delete _M_category_names;
       throw;
     }
-#endif
   }
   
   locale::_Impl::_Impl(const _Impl& __other, size_t __refs)
@@ -87,7 +83,6 @@ namespace std {
   , _M_cached_name_ok(__other._M_cached_name_ok)
   , _M_cached_name(__other._M_cached_name)
   {
-#if 1
     typedef vector<facet*, __STL_DEFAULT_ALLOCATOR(facet*) > __vec_facet;
     typedef vector<string, __STL_DEFAULT_ALLOCATOR(string) > __vec_string;
     try {
@@ -104,14 +99,12 @@ namespace std {
       delete _M_category_names;
       throw;
     }
-#endif
 
     std::vector<facet*>::iterator __it = _M_facets->begin();
     for (; __it != _M_facets->end(); ++__it)
       (*__it)->_M_add_reference();
   }
   
-  //////////
   void
   locale::_Impl::_M_replace_categories(const _Impl* __other, category __cats)
   {
@@ -128,7 +121,6 @@ namespace std {
       }
   }
 
-  //////////
   void
   locale::_Impl::_M_replace_category(const _Impl* __other,
 				     const locale::id* const* __idpp)
@@ -137,7 +129,6 @@ namespace std {
       _M_replace_facet(__other, *__idpp);
   }
   
-  //////////
   void
   locale::_Impl::_M_replace_facet(const _Impl* __other, 
 				  const locale::id* __idp)
@@ -151,7 +142,6 @@ namespace std {
     _M_install_facet(__idp, (*(__other->_M_facets))[__index]); 
   }
 
-  //////////
   void
   locale::_Impl::_M_install_facet(const locale::id* __idp, facet* __fp)
   {
@@ -173,56 +163,95 @@ namespace std {
   }
 
   // locale facet category descriptions
-  //////////
   const locale::id* const
   locale::_Impl::_S_id_collate[] =
   {
     &std::collate<char>::id,
+#ifdef _GLIBCPP_USE_WCHAR_T
     &std::collate<wchar_t>::id,
+#endif
     0
   };
   
   const locale::id* const
   locale::_Impl::_S_id_ctype[] =
   {
-    &std::ctype<char>::id, &std::ctype<wchar_t>::id,
+    &std::ctype<char>::id, 
+#ifdef _GLIBCPP_USE_WCHAR_T
+    &std::ctype<wchar_t>::id,
+#endif
     &std::codecvt<char, char, mbstate_t>::id,
+#ifdef _GLIBCPP_USE_WCHAR_T
     &std::codecvt<wchar_t, char, mbstate_t>::id,
+#endif
     0
   };
 
   const locale::id* const
   locale::_Impl::_S_id_monetary[] =
   {
-    &std::moneypunct<char, false>::id, &std::moneypunct<wchar_t, false>::id,
-    &std::moneypunct<char,true >::id, &std::moneypunct<wchar_t,true >::id,
-    &std::money_get<char>::id,        &std::money_get<wchar_t>::id,
-    &std::money_put<char>::id,        &std::money_put<wchar_t>::id,
+    &std::moneypunct<char, false>::id, 
+#ifdef _GLIBCPP_USE_WCHAR_T
+    &std::moneypunct<wchar_t, false>::id,
+#endif
+    &std::moneypunct<char,true >::id, 
+#ifdef _GLIBCPP_USE_WCHAR_T
+    &std::moneypunct<wchar_t,true >::id,
+#endif
+    &std::money_get<char>::id,        
+#ifdef _GLIBCPP_USE_WCHAR_T
+    &std::money_get<wchar_t>::id,
+#endif
+    &std::money_put<char>::id,        
+#ifdef _GLIBCPP_USE_WCHAR_T
+    &std::money_put<wchar_t>::id,
+#endif
     0
   };
 
   const locale::id* const
   locale::_Impl::_S_id_numeric[] =
   {
-    &std::numpunct<char>::id, &std::numpunct<wchar_t>::id,
-    &std::num_get<char>::id,  &std::num_get<wchar_t>::id,
-    &std::num_put<char>::id,  &std::num_put<wchar_t>::id,
+    &std::numpunct<char>::id, 
+#ifdef _GLIBCPP_USE_WCHAR_T
+    &std::numpunct<wchar_t>::id,
+#endif
+    &std::num_get<char>::id,  
+ #ifdef _GLIBCPP_USE_WCHAR_T
+    &std::num_get<wchar_t>::id,
+#endif
+    &std::num_put<char>::id,  
+#ifdef _GLIBCPP_USE_WCHAR_T
+    &std::num_put<wchar_t>::id,
+#endif
     0
   };
   
   const locale::id* const
   locale::_Impl::_S_id_time[] =
   {
-    &std::time_get<char>::id, &std::time_get<wchar_t>::id,
-    &std::time_put<char>::id, &std::time_put<wchar_t>::id,
+    &std::time_get<char>::id, 
+#ifdef _GLIBCPP_USE_WCHAR_T
+    &std::time_get<wchar_t>::id,
+#endif
+    &std::time_put<char>::id, 
+#ifdef _GLIBCPP_USE_WCHAR_T
+    &std::time_put<wchar_t>::id,
+#endif
     0
   };
   
   const locale::id* const
   locale::_Impl::_S_id_messages[] =
   {
-    &std::time_get<char>::id, &std::time_get<wchar_t>::id,
-    &std::time_put<char>::id, &std::time_put<wchar_t>::id,
+    &std::time_get<char>::id, 
+#ifdef _GLIBCPP_USE_WCHAR_T
+    &std::time_get<wchar_t>::id,
+#endif
+    &std::time_put<char>::id, 
+#ifdef _GLIBCPP_USE_WCHAR_T
+    &std::time_put<wchar_t>::id,
+#endif
     0
   };
   
@@ -239,24 +268,13 @@ namespace std {
     0
   };
   
-  ///////////////////////////////////
-  // Implementation of locale members
-  ///////////////////////////////////
-
-  // locale static data
-  /////////////////////
   locale::_Impl* locale::_S_global;  // init'd to 0 before static ctors run
   locale::_Impl* locale::_S_classic; // init'd to 0 before static ctors run
 
-  // locale constructors
-  //////////////////////
-  
-  ////////
   locale::locale(_Impl* __ip) throw ()
   : _M_impl(__ip)
   { __ip->_M_add_reference(); }
 
-  //////////
   locale::locale(const locale& __other, const locale& __one, category __cats)
   {
     __cats = _S_normalize_category(__cats);    // might throw
@@ -275,11 +293,6 @@ namespace std {
       _M_impl->_M_has_name = false;
   }
 
-
-  // other locale members
-  ///////////////////////
-
-  ///////
   const locale&
   locale::operator=(const locale& __other) throw ()
   {
@@ -325,45 +338,47 @@ namespace std {
 	  // one reference for _M_classic, one for _M_global
 	  // (constructor for (*the_classic_locale) adds a third)
 	    
-	    
 	  // collate category
 	  _S_classic->_M_init_facet(new std::collate<char>);
-	  _S_classic->_M_init_facet(new std::collate<wchar_t>);
 	  
 	  // ctype category
 	  _S_classic->_M_init_facet(new std::ctype<char>);
-	  _S_classic->_M_init_facet(new std::ctype<wchar_t>);
 	  _S_classic->_M_init_facet(new std::codecvt<char, char, mbstate_t>);
-	  _S_classic->_M_init_facet(new std::codecvt<wchar_t, char, mbstate_t>);
-	  
+
 	  // monetary category
 	  _S_classic->_M_init_facet(new std::moneypunct<char, false>);
-	  _S_classic->_M_init_facet(new std::moneypunct<wchar_t, false>);
 	  _S_classic->_M_init_facet(new std::moneypunct<char,true >);
-	  _S_classic->_M_init_facet(new std::moneypunct<wchar_t,true >);
 	  _S_classic->_M_init_facet(new std::money_get<char>);
-	  _S_classic->_M_init_facet(new std::money_get<wchar_t>);
 	  _S_classic->_M_init_facet(new std::money_put<char>);
-	  _S_classic->_M_init_facet(new std::money_put<wchar_t>);
 	  
 	  // numeric category
 	  _S_classic->_M_init_facet(new std::numpunct<char>);
-	  _S_classic->_M_init_facet(new std::numpunct<wchar_t>);
 	  _S_classic->_M_init_facet(new std::num_get<char>);
-	  _S_classic->_M_init_facet(new std::num_get<wchar_t>);
 	  _S_classic->_M_init_facet(new std::num_put<char>);
-	  _S_classic->_M_init_facet(new std::num_put<wchar_t>);
 	  
 	  // time category
 	  _S_classic->_M_init_facet(new std::time_get<char>);
-	  _S_classic->_M_init_facet(new std::time_get<wchar_t>);
 	  _S_classic->_M_init_facet(new std::time_put<char>);
-	  _S_classic->_M_init_facet(new std::time_put<wchar_t>);
 	  
 	  // messages category
 	  _S_classic->_M_init_facet(new std::messages<char>);
+
+#ifdef  _GLIBCPP_USE_WCHAR_T
+	  _S_classic->_M_init_facet(new std::collate<wchar_t>);
+	  _S_classic->_M_init_facet(new std::ctype<wchar_t>);
+	  _S_classic->_M_init_facet(new std::codecvt<wchar_t, char, mbstate_t>);
+	  _S_classic->_M_init_facet(new std::moneypunct<wchar_t, false>);
+	  _S_classic->_M_init_facet(new std::moneypunct<wchar_t,true >);
+	  _S_classic->_M_init_facet(new std::money_get<wchar_t>);
+	  _S_classic->_M_init_facet(new std::money_put<wchar_t>);
+	  _S_classic->_M_init_facet(new std::numpunct<wchar_t>);
+	  _S_classic->_M_init_facet(new std::num_get<wchar_t>);
+	  _S_classic->_M_init_facet(new std::num_put<wchar_t>);
+	  _S_classic->_M_init_facet(new std::time_get<wchar_t>);
+	  _S_classic->_M_init_facet(new std::time_put<wchar_t>);
 	  _S_classic->_M_init_facet(new std::messages<wchar_t>);
-	  
+#endif	  
+
 	  // finesse static init order hassles
 	  __classic_locale = new locale(_S_classic);
 	}
@@ -382,14 +397,13 @@ namespace std {
     return *__classic_locale;
   }
 
-  ///////
   int
   locale::_S_normalize_category(int __cats) 
   {
     if ((__cats & all) && !(__cats & ~all))
       return __cats;
 
-    // may be a C-style "LC_ALL" category; convert.
+    // NB: May be a C-style "LC_ALL" category; convert.
     switch (__cats)
       {
       case LC_COLLATE:  return collate; 
@@ -408,10 +422,6 @@ namespace std {
     /* NOTREACHED */
   }
 
-//////////////////////////////////
-// Implementation of locale::facet
-//////////////////////////////////
-
   locale::facet::facet(size_t __refs) throw ()
   : _M_num_references(__refs - 1) 
   { }
@@ -442,25 +452,14 @@ namespace std {
 
   _Bad_use_facet::~_Bad_use_facet() throw() {}
   
-///////////////////////////////
-// Implementation of locale::id
-///////////////////////////////
-
   size_t locale::id::_S_highwater;  // init'd to 0 by linker
 
-  
-//////////////////////////////////
-// Implementation of ctype<char>.
-//////////////////////////////////
-  
-
-  /////////
   locale::id ctype<char>::id;
 
   ctype<char>::~ctype()
   { if (_M_del) delete[] table (); }
 
-#if defined(__GLIBC__) && (__GLIBC__ >= 2)
+#if defined(__GLIBC__) && (__GLIBC__ >= 2) && defined(_GLIBCPP_USE_CTYPE_ISBIT)
   // XXX these are Glibc-specific.
   const int* const& ctype<char>::_S_toupper = __ctype_toupper;
   const int* const& ctype<char>::_S_tolower = __ctype_tolower;
@@ -534,11 +533,158 @@ namespace std {
     return __high;
   }
 
+  template<>
+    ctype_byname<char>::ctype_byname(const char* __s, size_t __refs)
+    : ctype<char> (new mask[table_size], true, __refs)
+    { }
   
-  ////////////
-  locale::id ctype<wchar_t>::id;
-#if defined(__GLIBC__) && (__GLIBC__ >= 2)
 
+  locale::id codecvt<char, char, mbstate_t>::id;
+
+  codecvt<char, char, mbstate_t>::codecvt(size_t __refs)
+  : _Codecvt<char, char, mbstate_t> (__refs)
+  { }
+
+  codecvt<char, char, mbstate_t>::~codecvt() { }
+  
+  codecvt_base::result
+  codecvt<char, char, mbstate_t>::
+  do_out(state_type& __state, const intern_type* __from, 
+	 const intern_type* __from_end, const intern_type*& __from_next,
+	 extern_type* __to, extern_type* __to_end, 
+	 extern_type*& __to_next) const
+  { 
+    size_t __sizefrom = __from_end - __from;
+    size_t __sizeto = __to_end - __to;
+    size_t __length = __sizefrom <= __sizeto ? __sizefrom : __sizeto;
+    memcpy(__to, __from, __length);
+    __from_next = __from; 
+    __to_next = __to;
+    return noconv;  
+  }
+  
+  codecvt_base::result
+  codecvt<char, char, mbstate_t>::
+  do_unshift(state_type& __state, extern_type* __to, extern_type* __to_limit,
+	     extern_type*& __to_next) const
+  { 
+    __to_next = __to; 
+    return noconv; 
+  }
+  
+  codecvt_base::result
+  codecvt<char, char, mbstate_t>::
+  do_in(state_type& __state, const extern_type* __from, 
+	const extern_type* __from_end, const extern_type*& __from_next,
+	intern_type* __to, intern_type* __to_end, 
+	intern_type*& __to_next) const
+  { 
+    size_t __sizefrom = __from_end - __from;
+    size_t __sizeto = __to_end - __to;
+    size_t __length = __sizefrom <= __sizeto ? __sizefrom : __sizeto;
+    memcpy(__to, __from, __length);
+    __from_next = __from; 
+    __to_next = __to;
+    return noconv;  
+  }
+  
+
+  int 
+  codecvt<char, char, mbstate_t>::do_encoding() const throw ()
+  { return 1; }
+  
+  bool 
+  codecvt<char, char, mbstate_t>::do_always_noconv() const throw ()
+  { return true; }
+  
+  int 
+  codecvt<char, char, mbstate_t>::
+  do_length (const state_type& __state, const extern_type* __from,
+	     const extern_type* __end, size_t __max) const
+  { return (__max < size_t(__end - __from)) ? __max : __end - __from; }
+  
+  int 
+  codecvt<char, char, mbstate_t>::do_max_length() const throw ()
+  { return 1; }
+  
+  codecvt_byname<char, char, mbstate_t>::
+  codecvt_byname(const char* __s, size_t __refs)
+  : codecvt<char, char, mbstate_t>(__refs)
+  { }
+
+  codecvt_byname<char, char, mbstate_t>::~codecvt_byname() { }
+
+  locale::id collate<char>::id;
+
+  collate<char>::collate(size_t __refs)
+  : _Collate<char> (__refs)
+  { }
+  
+  collate<char>::~collate() { }
+  
+  int 
+  collate<char>::do_compare(const char* __lo1, const char* __hi1,
+			    const char* __lo2, const char* __hi2) const
+  {
+    for (; __lo1 < __hi1 && __lo2 < __hi2; ++__lo1, ++__lo2) 
+      if (*__lo1 != *__lo2) 
+	return (*__lo1 < *__lo2) ? -1 : 1;
+    if (__lo1 < __hi1) 
+      return 1;
+    else if (__lo2 < __hi2) 
+      return -1;
+    else 
+      return 0;
+  }
+  
+  string
+  collate<char>::do_transform(const char* __lo, const char* __hi) const
+  {
+    return string(__lo, __hi - __lo);
+  }
+  
+  long
+  collate<char>::do_hash(const char* __lo, const char* __hi) const
+  {
+    unsigned long __val = 0xdeadbeef;
+    for (; __lo < __hi; ++__lo)
+      __val = *__lo ^ ((__val << 7) & 
+		   (__val >> (numeric_limits<unsigned long>::digits - 1)));
+    return __val;
+  }
+  
+  template<>
+    collate_byname<char>::collate_byname(const char* __s, size_t __refs)
+    : collate<char> (__refs)
+    { }
+
+  template<>
+    numpunct_byname<char>::numpunct_byname(const char* __s, size_t __refs)
+    : numpunct<char> (__refs)
+    { }
+
+
+  template<>
+    moneypunct_byname<char, false>::
+    moneypunct_byname(const char* __s, size_t __refs)
+    : moneypunct<char, false> (__refs)
+    { }
+  
+  template<>
+    moneypunct_byname<char, true>::
+    moneypunct_byname(const char* __s, size_t __refs)
+    : moneypunct<char, true> (__refs)
+    { }
+  
+  template<>
+    messages_byname<char>::messages_byname(const char* __s, size_t __refs)
+    : messages<char> (__refs)
+    { }
+
+#ifdef _GLIBCPP_USE_WCHAR_T  
+  locale::id ctype<wchar_t>::id;
+
+#if defined(__GLIBC__) && (__GLIBC__ >= 2) && defined(_GLIBCPP_USE_CTYPE_ISBIT)
   // XXX These are Glibc-specific.
   const int* const& ctype<wchar_t>::_S_toupper = __ctype_toupper;
   const int* const& ctype<wchar_t>::_S_tolower = __ctype_tolower;
@@ -651,88 +797,11 @@ namespace std {
     return __high;
   }
 
-  template<>
-    ctype_byname<char>::ctype_byname(const char* __s, size_t __refs)
-    : ctype<char> (new mask[table_size], true, __refs)
-    { }
-  
   template<>
     ctype_byname<wchar_t>::ctype_byname(const char* __s, size_t __refs)
     : ctype<wchar_t> (__refs)
     { }
- 
 
-  ///////////
-  locale::id codecvt<char, char, mbstate_t>::id;
-
-  codecvt<char, char, mbstate_t>::codecvt(size_t __refs)
-  : _Codecvt<char, char, mbstate_t> (__refs)
-  { }
-
-  codecvt<char, char, mbstate_t>::~codecvt() { }
-  
-  codecvt_base::result
-  codecvt<char, char, mbstate_t>::
-  do_out(state_type& __state, const intern_type* __from, 
-	 const intern_type* __from_end, const intern_type*& __from_next,
-	 extern_type* __to, extern_type* __to_end, 
-	 extern_type*& __to_next) const
-  { 
-    size_t __sizefrom = __from_end - __from;
-    size_t __sizeto = __to_end - __to;
-    size_t __length = __sizefrom <= __sizeto ? __sizefrom : __sizeto;
-    memcpy(__to, __from, __length);
-    __from_next = __from; 
-    __to_next = __to;
-    return noconv;  
-  }
-  
-  codecvt_base::result
-  codecvt<char, char, mbstate_t>::
-  do_unshift(state_type& __state, extern_type* __to, extern_type* __to_limit,
-	     extern_type*& __to_next) const
-  { 
-    __to_next = __to; 
-    return noconv; 
-  }
-  
-  codecvt_base::result
-  codecvt<char, char, mbstate_t>::
-  do_in(state_type& __state, const extern_type* __from, 
-	const extern_type* __from_end, const extern_type*& __from_next,
-	intern_type* __to, intern_type* __to_end, 
-	intern_type*& __to_next) const
-  { 
-    size_t __sizefrom = __from_end - __from;
-    size_t __sizeto = __to_end - __to;
-    size_t __length = __sizefrom <= __sizeto ? __sizefrom : __sizeto;
-    memcpy(__to, __from, __length);
-    __from_next = __from; 
-    __to_next = __to;
-    return noconv;  
-  }
-  
-
-  int 
-  codecvt<char, char, mbstate_t>::do_encoding() const throw ()
-  { return 1; }
-  
-  bool 
-  codecvt<char, char, mbstate_t>::do_always_noconv() const throw ()
-  { return true; }
-  
-  int 
-  codecvt<char, char, mbstate_t>::
-  do_length (const state_type& __state, const extern_type* __from,
-	     const extern_type* __end, size_t __max) const
-  { return (__max < size_t(__end - __from)) ? __max : __end - __from; }
-  
-  int 
-  codecvt<char, char, mbstate_t>::do_max_length() const throw ()
-  { return 1; }
-  
-
-  //////////////////
   locale::id codecvt<wchar_t, char, mbstate_t>::id;
 
   codecvt<wchar_t, char, mbstate_t>::codecvt (size_t __refs)
@@ -793,14 +862,6 @@ namespace std {
   int 
   codecvt<wchar_t, char, mbstate_t>::do_max_length() const throw ()
   { return 1; }
-  
-
-  codecvt_byname<char, char, mbstate_t>::
-  codecvt_byname(const char* __s, size_t __refs)
-  : codecvt<char, char, mbstate_t>(__refs)
-  { }
-
-  codecvt_byname<char, char, mbstate_t>::~codecvt_byname() { }
 
   codecvt_byname<wchar_t, char, mbstate_t>::
   codecvt_byname(const char* __s, size_t __refs)
@@ -810,47 +871,6 @@ namespace std {
   
   codecvt_byname<wchar_t, char, mbstate_t>::~codecvt_byname() {}
 
-  ///////
-  locale::id collate<char>::id;
-
-  collate<char>::collate(size_t __refs)
-  : _Collate<char> (__refs)
-  {
-  }
-  
-  collate<char>::~collate() { }
-  
-  int collate<char>::do_compare(const char* __lo1, const char* __hi1,
-				const char* __lo2, const char* __hi2) const
-  {
-    for (; __lo1 < __hi1 && __lo2 < __hi2; ++__lo1, ++__lo2) 
-      if (*__lo1 != *__lo2) 
-	return (*__lo1 < *__lo2) ? -1 : 1;
-    if (__lo1 < __hi1) 
-      return 1;
-    else if (__lo2 < __hi2) 
-      return -1;
-    else 
-      return 0;
-  }
-  
-  string
-  collate<char>::do_transform(const char* __lo, const char* __hi) const
-  {
-    return string(__lo, __hi - __lo);
-  }
-  
-  long
-  collate<char>::do_hash(const char* __lo, const char* __hi) const
-  {
-    unsigned long __val = 0xdeadbeef;
-    for (; __lo < __hi; ++__lo)
-      __val = *__lo ^ ((__val << 7) & 
-		   (__val >> (numeric_limits<unsigned long>::digits - 1)));
-    return __val;
-  }
-  
-  //////////
   locale::id collate<wchar_t>::id;
 
   collate<wchar_t>::collate(size_t __refs)
@@ -878,16 +898,6 @@ namespace std {
     return 0; // XXX not done
   }
 
-  template<>
-    collate_byname<char>::collate_byname(const char* __s, size_t __refs)
-    : collate<char> (__refs)
-    { }
-
-  template<>
-    numpunct_byname<char>::numpunct_byname(const char* __s, size_t __refs)
-    : numpunct<char> (__refs)
-    { }
-
   template<>
     numpunct_byname<wchar_t>::numpunct_byname(const char* __s, size_t __refs)
     : numpunct<wchar_t> (__refs)
@@ -898,18 +908,6 @@ namespace std {
     : collate<wchar_t> (__refs)
     { }
   
-  template<>
-    moneypunct_byname<char, false>::
-    moneypunct_byname(const char* __s, size_t __refs)
-    : moneypunct<char, false> (__refs)
-    { }
-  
-  template<>
-    moneypunct_byname<char, true>::
-    moneypunct_byname(const char* __s, size_t __refs)
-    : moneypunct<char, true> (__refs)
-    { }
-  
   template<>
     moneypunct_byname<wchar_t, false>::
     moneypunct_byname(const char* __s, size_t __refs)
@@ -921,16 +919,12 @@ namespace std {
     moneypunct_byname(const char* __s, size_t __refs)
     : moneypunct<wchar_t, true> (__refs)
     { }
-  
-  template<>
-    messages_byname<char>::messages_byname(const char* __s, size_t __refs)
-    : messages<char> (__refs)
-    { }
-  
+    
   template<>
     messages_byname<wchar_t>::messages_byname(const char* __s, size_t __refs)
     : messages<wchar_t> (__refs)
     { }
+#endif //  _GLIBCPP_USE_WCHAR_T
 
 } // namespace std
 
